@@ -172,6 +172,11 @@ impl PolyhedronPy {
         return Ok(self.variables.to_vec())
     } 
 
+    #[getter]
+    pub fn index(&self) -> PyResult<Vec<Option<u32>>> {
+        return Ok(self.index.to_vec())
+    } 
+
     pub fn solve(&self, objectives: Vec<HashMap<u32, f64>>) -> Vec<IntegerSolutionPy> {
         let polyhedron = Polyhedron {
             a: Matrix {
@@ -295,20 +300,36 @@ impl GeLineqPy {
         }
     }
 }
+#[pyclass]
+#[derive(Clone)]
+pub enum SignPy {
+    Positive,
+    Negative 
+}
+
+impl SignPy{
+    fn convert(&self) -> Sign{
+        return match self {
+            SignPy::Positive => Sign::Positive,
+            SignPy::Negative => Sign::Negative
+        }
+    }
+}
 
 #[pyclass]
 #[derive(Clone)]
 pub struct AtLeastPy {
     ids: Vec<u32>,
-    bias: i64
+    bias: i64,
+    sign: SignPy
 }
 
 #[pymethods]
 impl AtLeastPy {
     
     #[new]
-    pub fn new(ids: Vec<u32>, bias: i64) -> AtLeastPy {
-        return AtLeastPy { ids: ids, bias: bias }
+    pub fn new(ids: Vec<u32>, bias: i64, sign: SignPy) -> AtLeastPy {
+        return AtLeastPy { ids: ids, bias: bias, sign: sign }
     }
 }
 
@@ -339,7 +360,8 @@ fn _to_theory_helper(theory_py: &TheoryPy) -> Theory {
                     Some(a) => Some(
                         AtLeast {
                             bias: a.bias,
-                            ids: a.ids.to_vec()
+                            ids: a.ids.to_vec(),
+                            sign: a.sign.convert()
                         }
                     ),
                     None => None
@@ -375,8 +397,8 @@ impl TheoryPy {
         }).collect()
     }
 
-    pub fn to_polyhedron(&self, active: bool, reduced: bool) -> PolyhedronPy {
-        let intern_polyhedron = _to_theory_helper(&self).to_polyhedron(active, reduced);
+    pub fn to_ge_polyhedron(&self, active: bool, reduced: bool) -> PolyhedronPy {
+        let intern_polyhedron = _to_theory_helper(&self).to_ge_polyhedron(active, reduced);
         return PolyhedronPy { 
             a: MatrixPy {
                 val: intern_polyhedron.a.val,
@@ -414,4 +436,4 @@ fn puan_rspy(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<AtLeastPy>()?;
     m.add_class::<GeLineqPy>()?;
     Ok(())
-}
\ No newline at end of file
+}
